fn insert_index(state: &mut State, key: &SubscriberKey, route: &RouteKey)Expand description
Indexes key under exact or wildcard, according to route.type_hint.
fn insert_index(state: &mut State, key: &SubscriberKey, route: &RouteKey)Indexes key under exact or wildcard, according to route.type_hint.